@@ -21,6 +21,7 @@ def foobar() -> int:
 
 EXPECTED_SERVER_FN_DEPLOYMENTS = '''# Poly deployed @ 2024-11-12T14:43:22.631113 - testing.foobar - https://na1.polyapi.io/canopy/polyui/collections/server-functions/jh23h5g3h5b24jh5b2j3h45v2jhg43v52j3h - 086aedd
 # Poly deployed @ 2024-11-11T14:43:22.631113 - testing.foobar - https://dev.polyapi.io/canopy/polyui/collections/server-functions/jh23h5g3h5b24jh5b2j3h45v2jhg43v52j3h - 086aedd
+
 from polyapi.typedefs import PolyServerFunction
 
 polyConfig: PolyServerFunction = {
@@ -76,6 +77,15 @@ def foobar(foo: str, bar: Dict[str, str]) -> int:
 '''
 
 class T(unittest.TestCase):
+    def test_parse_and_write_deployment_comment(self):
+        test_deployable = parse_function_code(EXPECTED_SERVER_FN_DEPLOYMENTS, "foobar")
+        deployable_comment_ranges = test_deployable["deploymentCommentRanges"]
+        updated_file_contents = update_deployment_comments(EXPECTED_SERVER_FN_DEPLOYMENTS, test_deployable)
+        self.assertEqual(updated_file_contents, EXPECTED_SERVER_FN_DEPLOYMENTS)
+        # Deployment comment ranges collapsed into one of equal size
+        self.assertEqual(test_deployable["deploymentCommentRanges"][0][0], deployable_comment_ranges[0][0])
+        self.assertEqual(test_deployable["deploymentCommentRanges"][0][1], deployable_comment_ranges[1][1])
+
     def test_write_deployment_comment(self):
         test_deployable = {
             "deployments": [
@@ -98,7 +108,7 @@ class T(unittest.TestCase):
                     'type': 'server-function'
                 }
             ],
-            "deploymentCommentRanges": [[0, 178]]
+            "deploymentCommentRanges": [[0, 177]]
         }
         updated_file_contents = update_deployment_comments(INITIAL_SERVER_FN_DEPLOYMENTS, test_deployable)
         self.assertEqual(updated_file_contents, EXPECTED_SERVER_FN_DEPLOYMENTS)
